==> json-joy-17.43.0.tgz: package/esm/json-crdt-peritext-ui/plugins/minimal/TopToolbar/index.js <==
// biome-ignore lint: React is used for JSX
import * as React from 'react';
import { Button } from '../../../components/Button';
import { CommonSliceType } from '../../../../json-crdt-extensions';
import { ButtonGroup } from '../../../components/ButtonGroup';
import { useSyncStore } from '../../../web/react/hooks';
import { ButtonSeparator } from '../../../components/ButtonSeparator';
export const TopToolbar = ({ ctx }) => {
    const peritext = ctx.peritext;
    const editor = peritext.editor;
    const pending = useSyncStore(editor.pending);
    if (!ctx.dom)
        return null;
    const cursor = editor.mainCursor();
    const [complete] = cursor ? peritext.overlay.stat(cursor) : [new Set()];
    const inlineGroupButton = (type, name) => (React.createElement(Button, { onClick: () => ctx.dom?.et.format('tog', type), onMouseDown: (e) => e.preventDefault(), active: (complete.has(type) && !pending?.has(type)) || (!complete.has(type) && pending?.has(type)) }, name));
    const button = (name, onClick) => (React.createElement(Button, { onClick: onClick, onMouseDown: (e) => e.preventDefault() }, name));
    const blockGroupButtom = (type, name) => (React.createElement(Button, { onClick: () => ctx.dom?.et.marker({ action: 'tog', type }), onMouseDown: (e) => e.preventDefault(), active: (complete.has(type) && !pending?.has(type)) || (!complete.has(type) && pending?.has(type)) }, name));
    return (React.createElement(ButtonGroup, { style: { marginBottom: 8 } },
        inlineGroupButton(CommonSliceType.b, 'Bold'),
        inlineGroupButton(CommonSliceType.i, 'Italic'),
        inlineGroupButton(CommonSliceType.u, 'Underline'),
        inlineGroupButton(CommonSliceType.overline, 'Overline'),
        inlineGroupButton(CommonSliceType.s, 'Strikethrough'),
        inlineGroupButton(CommonSliceType.code, 'Code'),
        inlineGroupButton(CommonSliceType.mark, 'Mark'),
        inlineGroupButton(CommonSliceType.del, 'Deleted'),
        inlineGroupButton(CommonSliceType.ins, 'Inserted'),
        inlineGroupButton(CommonSliceType.sup, 'Superscript'),
        inlineGroupButton(CommonSliceType.sub, 'Subscript'),
        inlineGroupButton(CommonSliceType.math, 'Math'),
        inlineGroupButton(CommonSliceType.kbd, 'Key'),
        inlineGroupButton(CommonSliceType.spoiler, 'Spoiler'),
        inlineGroupButton(CommonSliceType.bookmark, 'Bookmark'),
        React.createElement(ButtonSeparator, null),
        button('Blue', () => {
            ctx.dom?.et.format('tog', CommonSliceType.col, 'one', '#07f');
        }),
        React.createElement(ButtonSeparator, null),
        button('Erase', () => {
            ctx.dom?.et.format({ action: 'erase' });
        }),
        button('Clear', () => {
            ctx.dom?.et.format({ action: 'del' });
        }),
        button('Delete block split', () => {
            ctx.dom?.et.marker({ action: 'del' });
        }),
        React.createElement(ButtonSeparator, null),
        blockGroupButtom(CommonSliceType.p, 'Paragraph'),
        blockGroupButtom(CommonSliceType.blockquote, 'Blockquote'),
        blockGroupButtom(CommonSliceType.codeblock, 'Code Block')));
};

==> json-joy-17.48.0.tgz: package/esm/json-crdt-peritext-ui/plugins/minimal/TopToolbar/index.js <==
// biome-ignore lint: React is used for JSX
import * as React from 'react';
import { Button } from '../../../components/Button';
import { CommonSliceType } from '../../../../json-crdt-extensions';
import { ButtonGroup } from '../../../components/ButtonGroup';
import { useSyncStore } from '../../../web/react/hooks';
import { ButtonSeparator } from '../../../components/ButtonSeparator';
export const TopToolbar = ({ ctx }) => {
    const peritext = ctx.peritext;
    const editor = peritext.editor;
    const pending = useSyncStore(editor.pending);
    if (!ctx.dom)
        return null;
    const cursor = editor.mainCursor();
    const [complete] = cursor ? peritext.overlay.stat(cursor) : [new Set()];
    const inlineGroupButton = (type, name) => (React.createElement(Button, { onClick: () => ctx.dom?.et.format('tog', type), onMouseDown: (e) => e.preventDefault(), active: (complete.has(type) && !pending?.has(type)) || (!complete.has(type) && pending?.has(type)) }, name));
    const button = (name, onClick) => (React.createElement(Button, { onClick: onClick, onMouseDown: (e) => e.preventDefault() }, name));
    const blockGroupButtom = (type, name) => (React.createElement(Button
    // onClick={() => ctx.dom?.et.marker({action: 'tog', type})}
    , { 
        // onClick={() => ctx.dom?.et.marker({action: 'tog', type})}
        onClick: () => { }, onMouseDown: (e) => e.preventDefault(), active: (complete.has(type) && !pending?.has(type)) || (!complete.has(type) && pending?.has(type)) }, name));
    return (React.createElement(ButtonGroup, { style: { marginBottom: 8 } },
        inlineGroupButton(CommonSliceType.b, 'Bold'),
        inlineGroupButton(CommonSliceType.i, 'Italic'),
        inlineGroupButton(CommonSliceType.u, 'Underline'),
        inlineGroupButton(CommonSliceType.overline, 'Overline'),
        inlineGroupButton(CommonSliceType.s, 'Strikethrough'),
        inlineGroupButton(CommonSliceType.code, 'Code'),
        inlineGroupButton(CommonSliceType.mark, 'Mark'),
        inlineGroupButton(CommonSliceType.del, 'Deleted'),
        inlineGroupButton(CommonSliceType.ins, 'Inserted'),
        inlineGroupButton(CommonSliceType.sup, 'Superscript'),
        inlineGroupButton(CommonSliceType.sub, 'Subscript'),
        inlineGroupButton(CommonSliceType.math, 'Math'),
        inlineGroupButton(CommonSliceType.kbd, 'Key'),
        inlineGroupButton(CommonSliceType.spoiler, 'Spoiler'),
        inlineGroupButton(CommonSliceType.bookmark, 'Bookmark'),
        React.createElement(ButtonSeparator, null),
        button('Blue', () => {
            ctx.dom?.et.format('tog', CommonSliceType.col, 'one', '#07f');
        }),
        React.createElement(ButtonSeparator, null),
        button('Erase', () => {
            ctx.dom?.et.format({ action: 'erase' });
        }),
        button('Clear', () => {
            ctx.dom?.et.format({ action: 'del' });
        }),
        button('Delete block split', () => {
            ctx.dom?.et.marker({ action: 'del' });
        }),
        React.createElement(ButtonSeparator, null),
        blockGroupButtom(CommonSliceType.p, 'Paragraph'),
        blockGroupButtom(CommonSliceType.blockquote, 'Blockquote'),
        blockGroupButtom(CommonSliceType.codeblock, 'Code Block')));
};
